%bcond_without  lib

%define major 3
%define libname %mklibname %{name} %{major}
%define develname %mklibname -d %{name}
%define sdevelname %mklibname -d -s %{name}
%define cvsver 3_99
%define version 3.99.0

%define patchver %(echo %{version}|cut -d. -f3)
%if %{?patchver}
%define tarballver %{version}
%else
%define tarballver %(echo %{version}|cut -d. -f1,2)
%endif

%define nspr_libname %mklibname nspr 4

# this seems fragile, so require the exact version or later (#58754)
%define sqlite3_version %(pkg-config --modversion sqlite3 &>/dev/null && pkg-config --modversion sqlite3 2>/dev/null || echo 0)
%define nspr_version %(pkg-config --modversion nspr &>/dev/null && pkg-config --modversion nspr 2>/dev/null || echo 0)

Name:		nss
Version:	3.99
Release:	%mkrel 1
Summary:	Network Security Services
Group:		System/Libraries
License:	MPLv1.1 or GPLv2+ or LGPLv2+
URL:		https://www.mozilla.org/projects/security/pki/nss/index.html
Source0:	https://ftp.mozilla.org/pub/mozilla.org/security/nss/releases/NSS_%{cvsver}_RTM/src/nss-%{tarballver}.tar.xz
# Numbered as in Fedora:
Source8:	nss.pc.in
Source9:	nss-config.in
Source10:	blank-cert8.db
Source11:	blank-key3.db
Source12:	blank-secmod.db
Source28:	nss-p11-kit.config
Patch0:		nss-no-rpath.patch
Patch4:		renegotiate-transitional.patch
Patch20:	nss-gcm-param-default-pkcs11v2.patch
%if %with lib
Requires:	crypto-policies
%endif
BuildRequires:	nspr-devel >= 4.31
BuildRequires:	pkgconfig(zlib)
# one should look in nss/lib/sqlite/README to check which version is "recommended"
BuildRequires:	pkgconfig(sqlite3) >= 3.7.17
Provides: nss-tools = %{version}-%{release}

%description
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled client and server
applications. Applications built with NSS can support SSL v2 and v3,
TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509 v3 certificates, and
other security standards. For detailed information on standards supported, see
https://www.mozilla.org/projects/security/pki/nss/overview.html.
%if %without lib

Note: This package currently contains the NSS binaries only. The
libraries have been not been included due to conflicts with the Mozilla
libraries.
%endif

%package doc
Summary:	Network Security Services (NSS) - Documentation
Group:		Documentation
BuildArch:	noarch

%description doc
Documentation for Network Security Services.

%if %with lib
%package -n %{libname}
Summary:	Network Security Services (NSS)
Group:		System/Libraries
Provides:	mozilla-nss = %{version}-%{release}
Requires(pre):	filesystem
Requires(post):	nss
Requires(post):	rpm-helper
Requires:	%{mklibname sqlite3_ 0} >= %{sqlite3_version}
Requires:	%{nspr_libname} >= %{nspr_version}
Requires:	p11-kit

%description -n %{libname}
Network Security Services (NSS) is a set of libraries designed to
support cross-platform development of security-enabled server
applications. Applications built with NSS can support SSL v2 and v3,
TLS, PKCS #5, PKCS #7, PKCS #11, PKCS
#12, S/MIME, X.509 v3 certificates, and other security standards. For
detailed information on standards supported, see
https://www.mozilla.org/projects/security/pki/nss/overview.html.

%package -n %{develname}
Summary:	Development libraries for Network Security Services
Group:		Development/Libraries
Requires(pre):	filesystem
Requires:	%{libname} = %{version}-%{release}
Requires:	libnspr-devel
BuildRequires:	xmlto
Provides:	libnss-devel = %{version}-%{release}
Provides:	nss-devel = %{version}-%{release}
# (cg) The -devel package doesn't generate these automatically.
%ifarch x86_64 aarch64
Provides: devel(libfreebl3(64bit))
Provides: devel(libnss3(64bit))
Provides: devel(libnssdbm3(64bit))
Provides: devel(libnssutil3(64bit))
Provides: devel(libsmime3(64bit))
Provides: devel(libsoftokn3(64bit))
Provides: devel(libssl3(64bit))
%else
Provides: devel(libfreebl3)
Provides: devel(libnss3)
Provides: devel(libnssdbm3)
Provides: devel(libnssutil3)
Provides: devel(libsmime3)
Provides: devel(libsoftokn3)
Provides: devel(libssl3)
%endif

%description -n %{develname}
Header files to doing development with Network Security Services.

%package -n %{sdevelname}
Summary:	Network Security Services (NSS) - static libraries
Group:		Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	%{develname} = %{version}-%{release}
Requires:	libnspr-devel >= %{nspr_version}
Provides:	libnss-static-devel = %{version}-%{release}
Provides:	nss-static-devel = %{version}-%{release}
Conflicts:	libopenssl-static-devel

%description -n %{sdevelname}
Static libraries for doing development with Network Security Services.
%endif

%prep
%setup -qn %{name}-%{tarballver}
%patch0 -p0
%patch4 -p0 -b .transitional
%patch20 -p0 -b .gcm-param-default

# https://bugzilla.redhat.com/show_bug.cgi?id=1247353
find nss/lib/libpkix -perm /u+x -type f -exec chmod -x {} \;


%build
%set_build_flags
# Enable compiler optimizations and disable debugging code
export BUILD_OPT=1
export OPTIMIZER="%{optflags}"
export XCFLAGS="%{optflags}"
export LDOPTS="$LDFLAGS"
export ARCHFLAG="$LDFLAGS"
export LIBDIR=%{_libdir}
export USE_SYSTEM_ZLIB=1
export ZLIB_LIBS="-lz"
export PKG_CONFIG_ALLOW_SYSTEM_LIBS=1
export PKG_CONFIG_ALLOW_SYSTEM_CFLAGS=1

export NSPR_INCLUDE_DIR=`/usr/bin/pkg-config --cflags-only-I nspr | sed 's/-I//'`
export NSPR_LIB_DIR=%{_libdir}
export MOZILLA_CLIENT=1
export NS_USE_GCC=1
export NSS_USE_SYSTEM_SQLITE=1
export NSS_ENABLE_ECC=1
export NSS_ALLOW_SSLKEYLOGFILE=1
export NSS_SEED_ONLY_DEV_URANDOM=1
%ifnarch noarch
%if 0%{__isa_bits} == 64
export USE_64=1
%endif
%endif

%make_build -j1 -C ./nss all
%make_build -C ./nss latest

OLD="$LD_LIBRARY_PATH"
libpath=`%{_bindir}/find ./dist/ -name "Linux*.*" -type d`
# to use the built libraries instead of requiring nss
# again as buildrequires
export LD_LIBRARY_PATH="$PWD/$libpath/lib"

pushd nss/lib/ckfw/builtins

%make_build clean
%make_build -j1

popd
export LD_LIBRARY_PATH="$OLD"

# build the man pages clean
pushd ./nss
%{__make} clean_docs build_docs
popd

# and copy them to the dist directory for %%install to find them
mkdir -p ./dist/docs/nroff
cp ./nss/doc/nroff/* ./dist/docs/nroff

%install
# There is no make install target so we'll do it ourselves.

pushd dist/$(uname -s)*

mkdir -p %{buildroot}%{_bindir}
cp -aL bin/* %{buildroot}%{_bindir}

%if %with lib
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}/nss
cp -aL ../public/nss/* %{buildroot}%{_includedir}/nss

cp -aL lib/libcrmf.a \
            lib/libnss.a \
            lib/libnssb.a \
            lib/libnssckfw.a \
	    lib/libnssutil.a \
            lib/libsmime.a \
            lib/libssl.a \
            %{buildroot}%{_libdir}

# Copy the binary libraries we want
for file in libsoftokn3.so libfreebl3.so libfreeblpriv3.so libnss3.so \
    libnssutil3.so libssl3.so libsmime3.so libnssdbm3.so
do
  install -m 755 lib/$file %{buildroot}%{_libdir}
done

ln -s %{_libdir}/pkcs11/p11-kit-trust.so %{buildroot}%{_libdir}/libnssckbi.so

# These ghost files will be generated in the post step
# Make sure chk files can be found in both places
for file in libsoftokn3.chk libfreebl3.chk libfreeblpriv3.chk
do
  touch %{buildroot}%{_libdir}/$file
done

mkdir -p %{buildroot}%{_libdir}/pkgconfig
cat %{SOURCE8} | sed -e "s,%%libdir%%,%{_libdir},g" \
                          -e "s,%%prefix%%,%{_prefix},g" \
                          -e "s,%%exec_prefix%%,%{_prefix},g" \
                          -e "s,%%includedir%%,%{_includedir}/nss,g" \
                          -e "s,%%NSS_VERSION%%,%{version},g" \
                          -e "s,%%NSPR_VERSION%%,%{nspr_version},g" \
			  > \
                          %{buildroot}%{_libdir}/pkgconfig/nss.pc

mkdir -p %{buildroot}%{_sysconfdir}/crypto-policies/local.d
install -p -m 644 %{SOURCE28} %{buildroot}%{_sysconfdir}/crypto-policies/local.d

%endif

popd

%if %with lib
NSS_VMAJOR=`cat nss/lib/nss/nss.h | grep "#define.*NSS_VMAJOR" | awk '{print $3}'`
NSS_VMINOR=`cat nss/lib/nss/nss.h | grep "#define.*NSS_VMINOR" | awk '{print $3}'`
NSS_VPATCH=`cat nss/lib/nss/nss.h | grep "#define.*NSS_VPATCH" | awk '{print $3}'`

mkdir -p %{buildroot}%{_bindir}
cat %{SOURCE9} | sed -e "s,@libdir@,%{_libdir},g" \
                               -e "s,@prefix@,%{_prefix},g" \
                               -e "s,@exec_prefix@,%{_prefix},g" \
                               -e "s,@includedir@,%{_includedir}/nss%{major},g" \
                               -e "s,@MOD_MAJOR_VERSION@,$NSS_VMAJOR,g" \
                               -e "s,@MOD_MINOR_VERSION@,$NSS_VMINOR,g" \
                               -e "s,@MOD_PATCH_VERSION@,$NSS_VPATCH,g" \
                               > %{buildroot}/%{_bindir}/nss-config
%endif

pushd nss/cmd/smimetools
install -m 0755 smime %{buildroot}%{_bindir}
perl -pi -e 's|/usr/local/bin|%{_bindir}|g' %{buildroot}%{_bindir}/smime
popd

# add docs
mkdir -p docs/SSLsample

mkdir -p docs/bltest
cp -a nss/cmd/bltest/tests/* docs/bltest/

mkdir -p docs/modutil
cp -a nss/cmd/modutil/*.html docs/modutil/

mkdir -p docs/signtool
cp -a nss/cmd/signtool/README docs/signtool/

mkdir -p docs/signver
cp -a nss/cmd/signver/examples/1/*.pl docs/signver/
cp -a nss/cmd/signver/examples/1/*.html docs/signver/

mkdir -p docs/ssltap
cp -a nss/cmd/ssltap/*.html docs/ssltap/

# Copy the man pages for the nss tools
mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 ./dist/docs/nroff/*.1 %{buildroot}%{_mandir}/man1

# Install the empty NSS db files
# Legacy db
mkdir -p %{buildroot}%{_sysconfdir}/pki/nssdb
install -p -m 644 %{SOURCE10} %{buildroot}%{_sysconfdir}/pki/nssdb/cert8.db
install -p -m 644 %{SOURCE11} %{buildroot}%{_sysconfdir}/pki/nssdb/key3.db
install -p -m 644 %{SOURCE12} %{buildroot}%{_sysconfdir}/pki/nssdb/secmod.db

%{_bindir}/find docs -type f | %{_bindir}/xargs -t perl -pi -e 's/\r$//g'

%multiarch_binaries %{buildroot}%{_bindir}/nss-config

%if %with lib
%posttrans
update-crypto-policies &> /dev/null || :

%pretrans -n %{libname}
if [ -f %{_libdir}/libnssckbi.so -a ! -L %{_libdir}/libnssckbi.so ]; then
  rm -f %{_libdir}/libnssckbi.so
fi

%post -n %{libname}
%create_ghostfile %{_libdir}/libsoftokn%{major}.chk root root 644
%create_ghostfile %{_libdir}/libfreebl%{major}.chk root root 644
%create_ghostfile %{_libdir}/libfreeblpriv%{major}.chk root root 644
%{_bindir}/shlibsign -i %{_libdir}/libsoftokn%{major}.so >/dev/null 2>/dev/null
%{_bindir}/shlibsign -i %{_libdir}/libfreebl%{major}.so >/dev/null 2>/dev/null
%{_bindir}/shlibsign -i %{_libdir}/libfreeblpriv%{major}.so >/dev/null 2>/dev/null
%endif

%files
%attr(0755,root,root) %{_bindir}/addbuiltin
%attr(0755,root,root) %{_bindir}/atob
%attr(0755,root,root) %{_bindir}/baddbdir
%attr(0755,root,root) %{_bindir}/base_gtest
%attr(0755,root,root) %{_bindir}/bltest
%attr(0755,root,root) %{_bindir}/btoa
%attr(0755,root,root) %{_bindir}/certdb_gtest
%attr(0755,root,root) %{_bindir}/certhigh_gtest
%attr(0755,root,root) %{_bindir}/certutil
%attr(0755,root,root) %{_bindir}/chktest
%attr(0755,root,root) %{_bindir}/cmsutil
%attr(0755,root,root) %{_bindir}/conflict
%attr(0755,root,root) %{_bindir}/crlutil
%attr(0755,root,root) %{_bindir}/crmftest
%attr(0755,root,root) %{_bindir}/cryptohi_gtest
%attr(0755,root,root) %{_bindir}/dbtest
%attr(0755,root,root) %{_bindir}/dbtool
%attr(0755,root,root) %{_bindir}/der_gtest
%attr(0755,root,root) %{_bindir}/derdump
%attr(0755,root,root) %{_bindir}/dertimetest
%attr(0755,root,root) %{_bindir}/digest
%attr(0755,root,root) %{_bindir}/ecperf
%attr(0755,root,root) %{_bindir}/encodeinttest
%attr(0755,root,root) %{_bindir}/fbectest
%attr(0755,root,root) %{_bindir}/fipstest
%attr(0755,root,root) %{_bindir}/freebl_gtest
%attr(0755,root,root) %{_bindir}/httpserv
%attr(0755,root,root) %{_bindir}/listsuites
%attr(0755,root,root) %{_bindir}/lowhashtest
%attr(0755,root,root) %{_bindir}/makepqg
%attr(0755,root,root) %{_bindir}/mangle
%attr(0755,root,root) %{_bindir}/modutil
%attr(0755,root,root) %{_bindir}/multinit
%attr(0755,root,root) %{_bindir}/nonspr10
%attr(0755,root,root) %{_bindir}/nss_bogo_shim
%attr(0755,root,root) %{_bindir}/nss-policy-check
%attr(0755,root,root) %{_bindir}/ocspclnt
%attr(0755,root,root) %{_bindir}/ocspresp
%attr(0755,root,root) %{_bindir}/oidcalc
%attr(0755,root,root) %{_bindir}/p7content
%attr(0755,root,root) %{_bindir}/p7env
%attr(0755,root,root) %{_bindir}/p7sign
%attr(0755,root,root) %{_bindir}/p7verify
%attr(0755,root,root) %{_bindir}/pk11ectest
%attr(0755,root,root) %{_bindir}/pk11gcmtest
%attr(0755,root,root) %{_bindir}/pk11importtest
%attr(0755,root,root) %{_bindir}/pk11mode
%attr(0755,root,root) %{_bindir}/pk11_gtest
%attr(0755,root,root) %{_bindir}/pk12util
%attr(0755,root,root) %{_bindir}/pk1sign
%attr(0755,root,root) %{_bindir}/pkix-errcodes
%attr(0755,root,root) %{_bindir}/pp
%attr(0755,root,root) %{_bindir}/pwdecrypt
%attr(0755,root,root) %{_bindir}/remtest
%attr(0755,root,root) %{_bindir}/rsaperf
%attr(0755,root,root) %{_bindir}/rsapoptst
%attr(0755,root,root) %{_bindir}/sdbthreadtst
%attr(0755,root,root) %{_bindir}/sdrtest
%attr(0755,root,root) %{_bindir}/secmodtest
%attr(0755,root,root) %{_bindir}/selfserv
%attr(0755,root,root) %{_bindir}/shlibsign
%attr(0755,root,root) %{_bindir}/signtool
%attr(0755,root,root) %{_bindir}/signver
%attr(0755,root,root) %{_bindir}/smime
%attr(0755,root,root) %{_bindir}/smime_gtest
%attr(0755,root,root) %{_bindir}/softoken_gtest
%attr(0755,root,root) %{_bindir}/ssl_gtest
%attr(0755,root,root) %{_bindir}/ssltap
%attr(0755,root,root) %{_bindir}/strsclnt
%attr(0755,root,root) %{_bindir}/symkeyutil
%attr(0755,root,root) %{_bindir}/tstclnt
%attr(0755,root,root) %{_bindir}/util_gtest
%attr(0755,root,root) %{_bindir}/validation
%attr(0755,root,root) %{_bindir}/vfychain
%attr(0755,root,root) %{_bindir}/vfyserv
%{_mandir}/man1/*
%dir %{_sysconfdir}/pki/nssdb
%config(noreplace) %{_sysconfdir}/pki/nssdb/cert8.db
%config(noreplace) %{_sysconfdir}/pki/nssdb/key3.db
%config(noreplace) %{_sysconfdir}/pki/nssdb/secmod.db
%if %with lib
%config(noreplace) %{_sysconfdir}/crypto-policies/local.d/nss-p11-kit.config
%endif

%files doc
%doc docs/*

%if %with lib
%files -n %{libname}
%{_libdir}/libfreebl%{major}.so
%{_libdir}/libfreeblpriv%{major}.so
%{_libdir}/libnss%{major}.so
%{_libdir}/libnssckbi.so
%{_libdir}/libsmime%{major}.so
%{_libdir}/libsoftokn%{major}.so
%{_libdir}/libssl%{major}.so
%{_libdir}/libnssutil%{major}.so
%{_libdir}/libnssdbm%{major}.so
%ghost %{_libdir}/libsoftokn%{major}.chk
%ghost %{_libdir}/libfreebl%{major}.chk
%ghost %{_libdir}/libfreeblpriv%{major}.chk

%files -n %{develname}
%{_bindir}/nss-config
%attr(0755,root,root) %{multiarch_bindir}/nss-config
%dir %{_includedir}/nss
%{_includedir}/nss/base64.h
%{_includedir}/nss/blapit.h
%{_includedir}/nss/certdb.h
%{_includedir}/nss/cert.h
%{_includedir}/nss/certt.h
%{_includedir}/nss/ciferfam.h
%{_includedir}/nss/cmmf.h
%{_includedir}/nss/cmmft.h
%{_includedir}/nss/cms.h
%{_includedir}/nss/cmsreclist.h
%{_includedir}/nss/cmst.h
%{_includedir}/nss/crmf.h
%{_includedir}/nss/crmft.h
%{_includedir}/nss/cryptohi.h
%{_includedir}/nss/cryptoht.h
%{_includedir}/nss/eccutil.h
%{_includedir}/nss/ecl-exp.h
%{_includedir}/nss/hasht.h
%{_includedir}/nss/jar-ds.h
%{_includedir}/nss/jarfile.h
%{_includedir}/nss/jar.h
%{_includedir}/nss/key.h
%{_includedir}/nss/keyhi.h
%{_includedir}/nss/keyt.h
%{_includedir}/nss/keythi.h
%{_includedir}/nss/kyber.h
%{_includedir}/nss/lowkeyi.h
%{_includedir}/nss/lowkeyti.h
%{_includedir}/nss/nssb64.h
%{_includedir}/nss/nssb64t.h
%{_includedir}/nss/nssbase.h
%{_includedir}/nss/nssbaset.h
%{_includedir}/nss/nssck.api
%{_includedir}/nss/nssckbi.h
%{_includedir}/nss/nssckepv.h
%{_includedir}/nss/nssckft.h
%{_includedir}/nss/nssckfwc.h
%{_includedir}/nss/nssckfw.h
%{_includedir}/nss/nssckfwt.h
%{_includedir}/nss/nssckg.h
%{_includedir}/nss/nssckmdt.h
%{_includedir}/nss/nssckt.h
%{_includedir}/nss/nss.h
%{_includedir}/nss/nssilckt.h
%{_includedir}/nss/nssilock.h
%{_includedir}/nss/nsslocks.h
%{_includedir}/nss/nsslowhash.h
%{_includedir}/nss/nssrwlk.h
%{_includedir}/nss/nssrwlkt.h
%{_includedir}/nss/nssutil.h
%{_includedir}/nss/ocsp.h
%{_includedir}/nss/ocspt.h
%{_includedir}/nss/p12.h
%{_includedir}/nss/p12plcy.h
%{_includedir}/nss/p12t.h
%{_includedir}/nss/pk11func.h
%{_includedir}/nss/pk11hpke.h
%{_includedir}/nss/pk11pqg.h
%{_includedir}/nss/pk11priv.h
%{_includedir}/nss/pk11pub.h
%{_includedir}/nss/pk11sdr.h
%{_includedir}/nss/pkcs11f.h
%{_includedir}/nss/pkcs11.h
%{_includedir}/nss/pkcs11n.h
%{_includedir}/nss/pkcs11p.h
%{_includedir}/nss/pkcs11t.h
%{_includedir}/nss/pkcs11u.h
%{_includedir}/nss/pkcs11uri.h
%{_includedir}/nss/pkcs12.h
%{_includedir}/nss/pkcs12t.h
%{_includedir}/nss/pkcs1sig.h
%{_includedir}/nss/pkcs7t.h
%{_includedir}/nss/portreg.h
%{_includedir}/nss/preenc.h
%{_includedir}/nss/secasn1.h
%{_includedir}/nss/secasn1t.h
%{_includedir}/nss/seccomon.h
%{_includedir}/nss/secder.h
%{_includedir}/nss/secdert.h
%{_includedir}/nss/secdig.h
%{_includedir}/nss/secdigt.h
%{_includedir}/nss/secerr.h
%{_includedir}/nss/sechash.h
%{_includedir}/nss/secitem.h
%{_includedir}/nss/secmime.h
%{_includedir}/nss/secmod.h
%{_includedir}/nss/secmodt.h
%{_includedir}/nss/secoid.h
%{_includedir}/nss/secoidt.h
%{_includedir}/nss/secpkcs5.h
%{_includedir}/nss/secpkcs7.h
%{_includedir}/nss/secport.h
%{_includedir}/nss/shsign.h
%{_includedir}/nss/smime.h
%{_includedir}/nss/sslerr.h
%{_includedir}/nss/sslexp.h
%{_includedir}/nss/ssl.h
%{_includedir}/nss/sslproto.h
%{_includedir}/nss/sslt.h
%{_includedir}/nss/utilmodt.h
%{_includedir}/nss/utilpars.h
%{_includedir}/nss/utilparst.h
%{_includedir}/nss/utilrename.h
%{_libdir}/pkgconfig/nss.pc
%{_libdir}/libsoftokn%{major}.chk
%{_libdir}/libfreebl%{major}.chk
%{_libdir}/libfreeblpriv%{major}.chk

%files -n %{sdevelname}
%{_libdir}/libcrmf.a
%{_libdir}/libnss.a
%{_libdir}/libnssutil.a
%{_libdir}/libnssb.a
%{_libdir}/libnssckfw.a
%{_libdir}/libsmime.a
%{_libdir}/libssl.a
%endif

%changelog
* Thu Mar 28 2024 tex - 3.99-1pclos2024
- new version

* Sun Feb 18 2024 tex - 3.98-1pclos2024
- new version

* Wed Jan 24 2024 tex - 3.97-1pclos2024
- new version

* Fri Dec 29 2023 tex - 3.96.1-1pclos2024
- new version

* Thu Nov 30 2023 tex - 3.95.0-1pclos2023
- new version

